==> python_imager-1.2.14-py3-none-any.whl: pyimager/colors.py <==
class colour:
    def new(hexadecimal='000000', tipe=False):
        '''Hexadecimal colour in RGB'''
        if type(hexadecimal) == int: hexadecimal = f'{hexadecimal:x}'
        hexadecimal = hexadecimal.replace('#','')
        if tipe: b, g, r = int(hexadecimal[0:2],base=16), int(hexadecimal[2:4],base=16), int(hexadecimal[4:6],base=16)
        else: r, g, b = int(hexadecimal[0:2],base=16), int(hexadecimal[2:4],base=16), int(hexadecimal[4:6],base=16)
        return[r,g,b]
    aliceBlue = new("#F0F8FF")
    antiqueWhite = new("#FAEBD7")
    aqua = new("#00FFFF")
    aquamarine = new("#7FFFD4")
    azure = new("#F0FFFF")
    beige = new("#F5F5DC")
    bisque = new("#FFE4C4")
    black = new("#000000")
    blanchedAlmond = new("#FFEBCD")
    blue = new("#0000FF")
    blueViolet = new("#8A2BE2")
    brown = new("#A52A2A")
    burlyWood = new("#DEB887")
    cadetBlue = new("#5F9EA0")
    chartreuse = new("#7FFF00")
    chocolourate = new("#D2691E")
    coral = new("#FF7F50")
    cornflowerBlue = new("#6495ED")
    cornsilk = new("#FFF8DC")
    crimson = new("#DC143C")
    cyan = new("#00FFFF")
    darkBlue = new("#00008B")
    darkCyan = new("#008B8B")
    darkGoldenRod = new("#B8860B")
    darkGray = new("#A9A9A9")
    darkGrey = new("#A9A9A9")
    darkGreen = new("#006400")
    darkKhaki = new("#BDB76B")
    darkMagenta = new("#8B008B")
    darkOliveGreen = new("#556B2F")
    darkOrange = new("#FF8C00")
    darkOrchid = new("#9932CC")
    darkRed = new("#8B0000")
    darkSalmon = new("#E9967A")
    darkSeaGreen = new("#8FBC8F")
    darkSlateBlue = new("#483D8B")
    darkSlateGray = new("#2F4F4F")
    darkSlateGrey = new("#2F4F4F")
    darkTurquoise = new("#00CED1")
    darkViolet = new("#9400D3")
    deepPink = new("#FF1493")
    deepSkyBlue = new("#00BFFF")
    dimGray = new("#696969")
    dimGrey = new("#696969")
    dodgerBlue = new("#1E90FF")
    fireBrick = new("#B22222")
    floralWhite = new("#FFFAF0")
    forestGreen = new("#228B22")
    fuchsia = new("#FF00FF")
    gainsboro = new("#DCDCDC")
    ghostWhite = new("#F8F8FF")
    gold = new("#FFD700")
    goldenRod = new("#DAA520")
    gray = new("#808080")
    grey = new("#808080")
    green = new("#008000")
    greenYellow = new("#ADFF2F")
    honeyDew = new("#F0FFF0")
    hotPink = new("#FF69B4")
    indianRed = new("#CD5C5C")
    indigo = new("#4B0082")
    ivory = new("#FFFFF0")
    khaki = new("#F0E68C")
    lavender = new("#E6E6FA")
    lavenderBlush = new("#FFF0F5")
    lawnGreen = new("#7CFC00")
    lemonChiffon = new("#FFFACD")
    lightBlue = new("#ADD8E6")
    lightCoral = new("#F08080")
    lightCyan = new("#E0FFFF")
    lightGoldenRodYellow = new("#FAFAD2")
    lightGray = new("#D3D3D3")
    lightGrey = new("#D3D3D3")
    lightGreen = new("#90EE90")
    lightPink = new("#FFB6C1")
    lightSalmon = new("#FFA07A")
    lightSeaGreen = new("#20B2AA")
    lightSkyBlue = new("#87CEFA")
    lightSlateGray = new("#778899")
    lightSlateGrey = new("#778899")
    lightSteelBlue = new("#B0C4DE")
    lightYellow = new("#FFFFE0")
    lime = new("#00FF00")
    limeGreen = new("#32CD32")
    linen = new("#FAF0E6")
    magenta = new("#FF00FF")
    maroon = new("#800000")
    mediumAquaMarine = new("#66CDAA")
    mediumBlue = new("#0000CD")
    mediumOrchid = new("#BA55D3")
    mediumPurple = new("#9370DB")
    mediumSeaGreen = new("#3CB371")
    mediumSlateBlue = new("#7B68EE")
    mediumSpringGreen = new("#00FA9A")
    mediumTurquoise = new("#48D1CC")
    mediumVioletRed = new("#C71585")
    midnightBlue = new("#191970")
    mintCream = new("#F5FFFA")
    mistyRose = new("#FFE4E1")
    moccasin = new("#FFE4B5")
    navajoWhite = new("#FFDEAD")
    navy = new("#000080")
    oldLace = new("#FDF5E6")
    olive = new("#808000")
    oliveDrab = new("#6B8E23")
    orange = new("#FFA500")
    orangeRed = new("#FF4500")
    orchid = new("#DA70D6")
    paleGoldenRod = new("#EEE8AA")
    paleGreen = new("#98FB98")
    paleTurquoise = new("#AFEEEE")
    paleVioletRed = new("#DB7093")
    papayaWhip = new("#FFEFD5")
    peachPuff = new("#FFDAB9")
    peru = new("#CD853F")
    pink = new("#FFC0CB")
    plum = new("#DDA0DD")
    powderBlue = new("#B0E0E6")
    purple = new("#800080")
    rebeccaPurple = new("#663399")
    red = new("#FF0000")
    rosyBrown = new("#BC8F8F")
    royalBlue = new("#4169E1")
    saddleBrown = new("#8B4513")
    salmon = new("#FA8072")
    sandyBrown = new("#F4A460")
    seaGreen = new("#2E8B57")
    seaShell = new("#FFF5EE")
    sienna = new("#A0522D")
    silver = new("#C0C0C0")
    skyBlue = new("#87CEEB")
    slateBlue = new("#6A5ACD")
    slateGray = new("#708090")
    slateGrey = new("#708090")
    snow = new("#FFFAFA")
    springGreen = new("#00FF7F")
    steelBlue = new("#4682B4")
    tan = new("#D2B48C")
    teal = new("#008080")
    thistle = new("#D8BFD8")
    tomato = new("#FF6347")
    turquoise = new("#40E0D0")
    violet = new("#EE82EE")
    wheat = new("#F5DEB3")
    white = new("#FFFFFF")
    whiteSmoke = new("#F5F5F5")
    yellow = new("#FFFF00")
    yellowGreen = new("#9ACD32")

==> python_imager-1.2.45-py3-none-any.whl: pyimager/colors.py <==
class colour:
    def new(hexadecimal='000000', tipe=False):
        '''Hexadecimal colour in RGB'''
        if type(hexadecimal) == int: hexadecimal = f'{hexadecimal:x}'
        elif type(hexadecimal) == list and len(hexadecimal)==3: return hexadecimal
        hexadecimal = hexadecimal.replace('#','')
        if tipe: b, g, r = int(hexadecimal[0:2],base=16), int(hexadecimal[2:4],base=16), int(hexadecimal[4:6],base=16)
        else: r, g, b = int(hexadecimal[0:2],base=16), int(hexadecimal[2:4],base=16), int(hexadecimal[4:6],base=16)
        return[r,g,b]
    def compl(colour):
        if type(colour) == str: colour = self.new(colour)
        return [255 - i for i in colour]
    aliceBlue = new("#F0F8FF")
    antiqueWhite = new("#FAEBD7")
    aqua = new("#00FFFF")
    aquamarine = new("#7FFFD4")
    azure = new("#F0FFFF")
    beige = new("#F5F5DC")
    bisque = new("#FFE4C4")
    black = new("#000000")
    blanchedAlmond = new("#FFEBCD")
    blue = new("#0000FF")
    blueViolet = new("#8A2BE2")
    brown = new("#A52A2A")
    burlyWood = new("#DEB887")
    cadetBlue = new("#5F9EA0")
    chartreuse = new("#7FFF00")
    chocolourate = new("#D2691E")
    coral = new("#FF7F50")
    cornflowerBlue = new("#6495ED")
    cornsilk = new("#FFF8DC")
    crimson = new("#DC143C")
    cyan = new("#00FFFF")
    darkBlue = new("#00008B")
    darkCyan = new("#008B8B")
    darkGoldenRod = new("#B8860B")
    darkGray = new("#A9A9A9")
    darkGrey = new("#A9A9A9")
    darkGreen = new("#006400")
    darkKhaki = new("#BDB76B")
    darkMagenta = new("#8B008B")
    darkOliveGreen = new("#556B2F")
    darkOrange = new("#FF8C00")
    darkOrchid = new("#9932CC")
    darkRed = new("#8B0000")
    darkSalmon = new("#E9967A")
    darkSeaGreen = new("#8FBC8F")
    darkSlateBlue = new("#483D8B")
    darkSlateGray = new("#2F4F4F")
    darkSlateGrey = new("#2F4F4F")
    darkTurquoise = new("#00CED1")
    darkViolet = new("#9400D3")
    deepPink = new("#FF1493")
    deepSkyBlue = new("#00BFFF")
    dimGray = new("#696969")
    dimGrey = new("#696969")
    dodgerBlue = new("#1E90FF")
    fireBrick = new("#B22222")
    floralWhite = new("#FFFAF0")
    forestGreen = new("#228B22")
    fuchsia = new("#FF00FF")
    gainsboro = new("#DCDCDC")
    ghostWhite = new("#F8F8FF")
    gold = new("#FFD700")
    goldenRod = new("#DAA520")
    gray = new("#808080")
    grey = new("#808080")
    green = new("#008000")
    greenYellow = new("#ADFF2F")
    honeyDew = new("#F0FFF0")
    hotPink = new("#FF69B4")
    indianRed = new("#CD5C5C")
    indigo = new("#4B0082")
    ivory = new("#FFFFF0")
    khaki = new("#F0E68C")
    lavender = new("#E6E6FA")
    lavenderBlush = new("#FFF0F5")
    lawnGreen = new("#7CFC00")
    lemonChiffon = new("#FFFACD")
    lightBlue = new("#ADD8E6")
    lightCoral = new("#F08080")
    lightCyan = new("#E0FFFF")
    lightGoldenRodYellow = new("#FAFAD2")
    lightGray = new("#D3D3D3")
    lightGrey = new("#D3D3D3")
    lightGreen = new("#90EE90")
    lightPink = new("#FFB6C1")
    lightSalmon = new("#FFA07A")
    lightSeaGreen = new("#20B2AA")
    lightSkyBlue = new("#87CEFA")
    lightSlateGray = new("#778899")
    lightSlateGrey = new("#778899")
    lightSteelBlue = new("#B0C4DE")
    lightYellow = new("#FFFFE0")
    lime = new("#00FF00")
    limeGreen = new("#32CD32")
    linen = new("#FAF0E6")
    magenta = new("#FF00FF")
    maroon = new("#800000")
    mediumAquaMarine = new("#66CDAA")
    mediumBlue = new("#0000CD")
    mediumOrchid = new("#BA55D3")
    mediumPurple = new("#9370DB")
    mediumSeaGreen = new("#3CB371")
    mediumSlateBlue = new("#7B68EE")
    mediumSpringGreen = new("#00FA9A")
    mediumTurquoise = new("#48D1CC")
    mediumVioletRed = new("#C71585")
    midnightBlue = new("#191970")
    mintCream = new("#F5FFFA")
    mistyRose = new("#FFE4E1")
    moccasin = new("#FFE4B5")
    navajoWhite = new("#FFDEAD")
    navy = new("#000080")
    oldLace = new("#FDF5E6")
    olive = new("#808000")
    oliveDrab = new("#6B8E23")
    orange = new("#FFA500")
    orangeRed = new("#FF4500")
    orchid = new("#DA70D6")
    paleGoldenRod = new("#EEE8AA")
    paleGreen = new("#98FB98")
    paleTurquoise = new("#AFEEEE")
    paleVioletRed = new("#DB7093")
    papayaWhip = new("#FFEFD5")
    peachPuff = new("#FFDAB9")
    peru = new("#CD853F")
    pink = new("#FFC0CB")
    plum = new("#DDA0DD")
    powderBlue = new("#B0E0E6")
    purple = new("#800080")
    rebeccaPurple = new("#663399")
    red = new("#FF0000")
    rosyBrown = new("#BC8F8F")
    royalBlue = new("#4169E1")
    saddleBrown = new("#8B4513")
    salmon = new("#FA8072")
    sandyBrown = new("#F4A460")
    seaGreen = new("#2E8B57")
    seaShell = new("#FFF5EE")
    sienna = new("#A0522D")
    silver = new("#C0C0C0")
    skyBlue = new("#87CEEB")
    slateBlue = new("#6A5ACD")
    slateGray = new("#708090")
    slateGrey = new("#708090")
    snow = new("#FFFAFA")
    springGreen = new("#00FF7F")
    steelBlue = new("#4682B4")
    tan = new("#D2B48C")
    teal = new("#008080")
    thistle = new("#D8BFD8")
    tomato = new("#FF6347")
    turquoise = new("#40E0D0")
    violet = new("#EE82EE")
    wheat = new("#F5DEB3")
    white = new("#FFFFFF")
    whiteSmoke = new("#F5F5F5")
    yellow = new("#FFFF00")
    yellowGreen = new("#9ACD32")
    help = red
